@@ -252,7 +252,7 @@ def worksheet_to_data(ws, locale=None, fs=None, default_cell_border="none"):
     return {"rows": data_list, "cols": col_list, "images": images_to_data(ws)}
 
 
-def render_table(data, append_headers, append_lineno):
+def render_table(data, append_headers, append_lineno, start, end):
     html = [
         "<table  "
         'style="border-collapse: collapse" '
@@ -275,6 +275,7 @@ def render_table(data, append_headers, append_lineno):
     append_headers(data, html)
 
     for i, row in enumerate(data["rows"]):
+        if i == end: break
         trow = [('<tr id="{}">').format(i)]
         append_lineno(trow, i)
         for cell in row:
@@ -337,7 +338,7 @@ def render_data_to_html(data, append_headers, append_lineno):
     </body>
     </html>
     """
-    return html % render_table(data, append_headers, append_lineno)
+    return html % render_table(data, append_headers, append_lineno, 0, 22)
 
 
 def get_sheet(wb, sheet):
